skhubness.analysis.Hubness
==========================

.. currentmodule:: skhubness.analysis

.. autoclass:: Hubness

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Hubness.__init__
      ~Hubness.antihub_occurrence
      ~Hubness.atkinson_index
      ~Hubness.estimate
      ~Hubness.fit_transform
      ~Hubness.gini_index
      ~Hubness.hub_occurrence
      ~Hubness.robinhood_index
      ~Hubness.skewness_truncnorm
   
   

   
   
   